@@ -20,6 +20,8 @@ class RuleMode(str, Enum):
     BLOCKING = "BLOCKING"
     MONITOR = "MONITOR"
     DEBUG = "DEBUG"
+    WHITELISTED = "WHITELISTED"
+    DISABLED = "DISABLED"
 
 
 class RuleRisk(str, Enum):
